@@ -45,7 +45,8 @@ def comb_df_by_group(df, group_names):
             combined_values.append(df[col].values.tolist())
         comb_list = [
             item for sublist in combined_values for item in sublist]
-        df_comb[group] = comb_list
+        df = pd.DataFrame({group: comb_list})
+        df_comb = pd.concat([df_comb, df], axis=1)
 
     return df_comb
 
